==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ForwardingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FrontDoorForwardingProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes Forwarding Route.
 * @property backendPool A reference to the BackendPool which this rule routes to.
 * @property cacheConfiguration The caching configuration associated with this rule.
 * @property customForwardingPath A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
 * @property forwardingProtocol Protocol this rule will use when forwarding traffic to backends.
 * @property odataType
 * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
 */
public data class ForwardingConfigurationArgs(
    public val backendPool: Output<SubResourceArgs>? = null,
    public val cacheConfiguration: Output<CacheConfigurationArgs>? = null,
    public val customForwardingPath: Output<String>? = null,
    public val forwardingProtocol: Output<Either<String, FrontDoorForwardingProtocol>>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs =
        com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs.builder()
            .backendPool(backendPool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .cacheConfiguration(
                cacheConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customForwardingPath(customForwardingPath?.applyValue({ args0 -> args0 }))
            .forwardingProtocol(
                forwardingProtocol?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ForwardingConfigurationArgs].
 */
@PulumiTagMarker
public class ForwardingConfigurationArgsBuilder internal constructor() {
    private var backendPool: Output<SubResourceArgs>? = null

    private var cacheConfiguration: Output<CacheConfigurationArgs>? = null

    private var customForwardingPath: Output<String>? = null

    private var forwardingProtocol: Output<Either<String, FrontDoorForwardingProtocol>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value A reference to the BackendPool which this rule routes to.
     */
    @JvmName("ruyxyoyappemqyio")
    public suspend fun backendPool(`value`: Output<SubResourceArgs>) {
        this.backendPool = value
    }

    /**
     * @param value The caching configuration associated with this rule.
     */
    @JvmName("dedcjqvvkemeaoob")
    public suspend fun cacheConfiguration(`value`: Output<CacheConfigurationArgs>) {
        this.cacheConfiguration = value
    }

    /**
     * @param value A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
     */
    @JvmName("rgtfdrsljyqifcat")
    public suspend fun customForwardingPath(`value`: Output<String>) {
        this.customForwardingPath = value
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("cumtcxmdxpdpipva")
    public suspend
    fun forwardingProtocol(`value`: Output<Either<String, FrontDoorForwardingProtocol>>) {
        this.forwardingProtocol = value
    }

    /**
     * @param value
     * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
     */
    @JvmName("gnhsiqvpiamtoowc")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value A reference to the BackendPool which this rule routes to.
     */
    @JvmName("ihytnrvaqqvjppwp")
    public suspend fun backendPool(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backendPool = mapped
    }

    /**
     * @param argument A reference to the BackendPool which this rule routes to.
     */
    @JvmName("gjvljclrkxjlhfov")
    public suspend fun backendPool(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backendPool = mapped
    }

    /**
     * @param value The caching configuration associated with this rule.
     */
    @JvmName("jrwuopmafhyjcmdc")
    public suspend fun cacheConfiguration(`value`: CacheConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cacheConfiguration = mapped
    }

    /**
     * @param argument The caching configuration associated with this rule.
     */
    @JvmName("hlffutwsjfcubnfk")
    public suspend
    fun cacheConfiguration(argument: suspend CacheConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = CacheConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cacheConfiguration = mapped
    }

    /**
     * @param value A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
     */
    @JvmName("mpmymqowgxkbuhwh")
    public suspend fun customForwardingPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customForwardingPath = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("yosonevhifcmdnyh")
    public suspend fun forwardingProtocol(`value`: Either<String, FrontDoorForwardingProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("olghgeeraraceolt")
    public fun forwardingProtocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FrontDoorForwardingProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("lecbvobgcqdgqoxs")
    public fun forwardingProtocol(`value`: FrontDoorForwardingProtocol) {
        val toBeMapped = Either.ofRight<String, FrontDoorForwardingProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value
     * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
     */
    @JvmName("onuynsnxiexaeyun")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): ForwardingConfigurationArgs = ForwardingConfigurationArgs(
        backendPool = backendPool,
        cacheConfiguration = cacheConfiguration,
        customForwardingPath = customForwardingPath,
        forwardingProtocol = forwardingProtocol,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ForwardingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FrontDoorForwardingProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes Forwarding Route.
 * @property backendPool A reference to the BackendPool which this rule routes to.
 * @property cacheConfiguration The caching configuration associated with this rule.
 * @property customForwardingPath A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
 * @property forwardingProtocol Protocol this rule will use when forwarding traffic to backends.
 * @property odataType
 * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
 */
public data class ForwardingConfigurationArgs(
    public val backendPool: Output<SubResourceArgs>? = null,
    public val cacheConfiguration: Output<CacheConfigurationArgs>? = null,
    public val customForwardingPath: Output<String>? = null,
    public val forwardingProtocol: Output<Either<String, FrontDoorForwardingProtocol>>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs =
        com.pulumi.azurenative.network.inputs.ForwardingConfigurationArgs.builder()
            .backendPool(backendPool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .cacheConfiguration(
                cacheConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customForwardingPath(customForwardingPath?.applyValue({ args0 -> args0 }))
            .forwardingProtocol(
                forwardingProtocol?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ForwardingConfigurationArgs].
 */
@PulumiTagMarker
public class ForwardingConfigurationArgsBuilder internal constructor() {
    private var backendPool: Output<SubResourceArgs>? = null

    private var cacheConfiguration: Output<CacheConfigurationArgs>? = null

    private var customForwardingPath: Output<String>? = null

    private var forwardingProtocol: Output<Either<String, FrontDoorForwardingProtocol>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value A reference to the BackendPool which this rule routes to.
     */
    @JvmName("ythimxtuskfpkdds")
    public suspend fun backendPool(`value`: Output<SubResourceArgs>) {
        this.backendPool = value
    }

    /**
     * @param value The caching configuration associated with this rule.
     */
    @JvmName("lysdxwaddsrkhkmd")
    public suspend fun cacheConfiguration(`value`: Output<CacheConfigurationArgs>) {
        this.cacheConfiguration = value
    }

    /**
     * @param value A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
     */
    @JvmName("euajekepucandxtg")
    public suspend fun customForwardingPath(`value`: Output<String>) {
        this.customForwardingPath = value
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("pqvcnrqfqatixcsw")
    public suspend
    fun forwardingProtocol(`value`: Output<Either<String, FrontDoorForwardingProtocol>>) {
        this.forwardingProtocol = value
    }

    /**
     * @param value
     * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
     */
    @JvmName("hvjsgnvxttwvoxux")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value A reference to the BackendPool which this rule routes to.
     */
    @JvmName("kcffgoicqjqtdmxw")
    public suspend fun backendPool(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backendPool = mapped
    }

    /**
     * @param argument A reference to the BackendPool which this rule routes to.
     */
    @JvmName("esscjwxvqgjngssa")
    public suspend fun backendPool(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backendPool = mapped
    }

    /**
     * @param value The caching configuration associated with this rule.
     */
    @JvmName("wgbdisaohblxahfs")
    public suspend fun cacheConfiguration(`value`: CacheConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cacheConfiguration = mapped
    }

    /**
     * @param argument The caching configuration associated with this rule.
     */
    @JvmName("wtgguwjqoqtcokrd")
    public suspend
    fun cacheConfiguration(argument: suspend CacheConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = CacheConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cacheConfiguration = mapped
    }

    /**
     * @param value A custom path used to rewrite resource paths matched by this rule. Leave empty to use incoming path.
     */
    @JvmName("kioocspgdgbxqavc")
    public suspend fun customForwardingPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customForwardingPath = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("dlfwkmefxfujalbj")
    public suspend fun forwardingProtocol(`value`: Either<String, FrontDoorForwardingProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("hbxrlwrxwbdrtwpd")
    public fun forwardingProtocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FrontDoorForwardingProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value Protocol this rule will use when forwarding traffic to backends.
     */
    @JvmName("qrbavctvrnkucnqw")
    public fun forwardingProtocol(`value`: FrontDoorForwardingProtocol) {
        val toBeMapped = Either.ofRight<String, FrontDoorForwardingProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forwardingProtocol = mapped
    }

    /**
     * @param value
     * Expected value is '#Microsoft.Azure.FrontDoor.Models.FrontdoorForwardingConfiguration'.
     */
    @JvmName("wglhmkvxvlmilydr")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): ForwardingConfigurationArgs = ForwardingConfigurationArgs(
        backendPool = backendPool,
        cacheConfiguration = cacheConfiguration,
        customForwardingPath = customForwardingPath,
        forwardingProtocol = forwardingProtocol,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}
